@@ -11,6 +11,13 @@ import gobject
 import import_data
 import db
 
+BEEP = "/usr/share/roadrunner/beep.wav"
+ABOUT_MESSAGE = """Roadrunner alerts You about speed cameras on the road.
+Local import supports GPX, CSV and ASC formats.
+
+<b>Maintainer : </b>David Hautbois
+<b>Email :</b> david.hautbois@free.fr"""
+
 class  roadrunnerApp(hildon.Program):
 
     def __init__(self):
@@ -24,6 +31,16 @@ class  roadrunnerApp(hildon.Program):
         self.alert = False
         
         self.mydb = db.radar_db()
+        
+        self.unit = self.mydb.get_config('unit')
+        if not self.unit: self.unit ='km'
+        self.timealert = self.mydb.get_config('timealert')
+        if not self.timealert: self.timealert ='30'
+        self.vibration = self.mydb.get_config('vibration')
+        if not self.vibration: self.vibration ='False'
+        self.sound = self.mydb.get_config('sound')
+        if not self.sound: self.sound ='False'
+        
         gtk.set_application_name("Roadrunner")
         
         self.control = location.GPSDControl.get_default()
@@ -45,7 +62,7 @@ class  roadrunnerApp(hildon.Program):
         # Only in Scratchbox
         #gobject.timeout_add(3000, self.test_alert)        
 
-        self.window = hildon.Window()
+        self.window = hildon.StackableWindow()
         self.add_window(self.window)
 
         menu_label = gtk.Label("Parameters")
@@ -60,6 +77,76 @@ class  roadrunnerApp(hildon.Program):
         self.build_window_alert()
         gtk.main()        
         
+        
+    def config_window(self,  window,  widget):
+        """Display confioguration window"""
+        
+        window = gtk.Dialog("Parameters", self.window,
+            gtk.DIALOG_MODAL,
+            (gtk.STOCK_OK, gtk.RESPONSE_YES,
+            gtk.STOCK_CANCEL, gtk.RESPONSE_NO))
+        km_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        km_button.set_label("Km")
+        mile_button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, km_button)
+        mile_button.set_label("Miles")
+        if self.unit == 'miles':
+            mile_button.set_active(True)    
+        hbox = gtk.HBox(False, 0)
+        hbox.pack_start(km_button, True, False, 0)
+        hbox.pack_start(mile_button, True, False, 0)
+        window.vbox.pack_start(hbox, True, False, 0)
+        hbox = gtk.HBox(False, 0)
+        hbox.pack_start(gtk.Label("Alert under (sec) : "), True, True, 0)
+        timealert_entry = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        timealert_entry.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        timealert_entry.set_text(self.timealert)
+        hbox.pack_start(timealert_entry)
+        window.vbox.pack_start(hbox, True, False, 0)
+        
+        vibration_cb = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        vibration_cb.set_label("Vibration")
+        if self.vibration =='True': 
+            vibration_cb.set_active(True)
+        window.vbox.pack_start(vibration_cb, True, False, 0)
+        
+        sound_cb = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        sound_cb.set_label("Beep")
+        if self.sound =='True': 
+            sound_cb.set_active(True)
+        window.vbox.pack_start(sound_cb, True, False, 0)
+        
+        window.vbox.show_all()
+
+        reponse = window.run()
+        if reponse == gtk.RESPONSE_YES:
+            if mile_button.get_active():
+                self.mydb.set_config('unit', 'miles')
+                self.unit = 'miles'
+            else:
+                self.mydb.set_config('unit', 'km')                
+                self.unit = 'km'
+            self.mydb.set_config('timealert', timealert_entry.get_text())
+            self.timealert = timealert_entry.get_text()
+            if vibration_cb.get_active():
+                self.mydb.set_config('vibration', 'True')
+                self.vibration = 'True'
+                print "Vibration enabled"
+            else:
+                self.mydb.set_config('vibration', 'False')
+                self.vibration = 'False'
+                print "Vibration disabled"
+            if sound_cb.get_active():
+                self.mydb.set_config('sound', 'True')
+                self.sound = 'True'
+                print "Beep enabled"
+            else:
+                self.mydb.set_config('sound', 'False')
+                self.sound = 'False'
+                print "Sound disabled"
+        else:
+            result = False
+        window.destroy()        
+        
 
     def imp_asc(self,  window,  widget):
         """Download and import speed cameras database"""
@@ -151,6 +238,8 @@ class  roadrunnerApp(hildon.Program):
                    import_data.import_gpxfile(localfile, self.pb)
                 elif localfile.endswith("csv"):
                    import_data.import_csvfile(localfile, self.pb)
+                elif localfile.endswith("asc"):
+                   import_data.import_csvfile(localfile, self.pb)
                 else:
                     self.warning_message("Unknown format\nCheck file extension")
             except Exception, err:
@@ -171,18 +260,26 @@ class  roadrunnerApp(hildon.Program):
         """Build the menu"""
         
         menu = hildon.AppMenu()
-        button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         button.set_label("Download speed cameras...")
         button.connect("clicked", self.imp_asc, None)
         menu.append(button)
-        button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         button.set_label("Import local file...")
         button.connect("clicked", self.imp_file, None)
         menu.append(button)
-        button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         button.set_label("Clear database...")
         button.connect("clicked", self.clear_database, None)
         menu.append(button)
+        button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        button.set_label("Parameters...")
+        button.connect("clicked", self.config_window, None)
+        menu.append(button)
+        button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        button.set_label("About...")
+        button.connect("clicked", self.display_about_dialog, None)
+        menu.append(button)
         menu.show_all()
         return menu
         
@@ -220,7 +317,7 @@ class  roadrunnerApp(hildon.Program):
                 print "latitude, longitude : %f, %f" % device.fix[4:6]
                 print "speed : %f" % device.fix[11]
                 
-            elif (str(device.fix[4]) != "nan") & (str(device.fix[5]) != "nan"):
+            elif (str(device.fix[4]) != "nan") & (str(device.fix[5]) != "nan") & (str(device.fix[11]) != "nan"):
                 print "Gps fix time changed"
                 print "time : %s" % time.strftime(
                                             "%d/%m/%Y %H:%M:%S",
@@ -228,15 +325,20 @@ class  roadrunnerApp(hildon.Program):
                 print "latitude, longitude : %f, %f" % device.fix[4:6]
                 print "speed : %f" % device.fix[11]
                 
+                if self.unit =='km':
+                    speed = device.fix[11]
+                else:
+                    speed = device.fix[11] / 1.6 
                 self.lastupdate_lbl.set_text("%s" % time.ctime(device.fix[2]))
                 self.latitude_lbl.set_text("%f" % device.fix[4])
                 self.longitude_lbl.set_text("%f" % device.fix[5])
-                self.speed_lbl.set_text("%f" % device.fix[11])
+                self.speed_lbl.set_text("%f" % speed)
                 self.previousfixtime = device.fix[2]
                 
                 print "Checking radar..."
                 (rid, rname, rdistance) = self.mydb.get_nearest_radar(
-                                                device.fix[4],  device.fix[5])
+                                                device.fix[4],  device.fix[5], 
+                                                float(self.timealert) * device.fix[11]/3600)
                 
                 if rid == -1: 
                     print "main : No radar detected"
@@ -245,14 +347,12 @@ class  roadrunnerApp(hildon.Program):
                     self.stop_alert()
                 else:
                     print "main : Radar detected"
-                    self.name_lbl.set_text(rname)
-                    if rdistance > 1:
+                    self.name_lbl.set_text(rname)                    
+                    if self.unit == 'miles':
                         print "%.03f" % rdistance
-                        self.distance_lbl.set_text("%.03f" % rdistance)
-                        pass
+                        self.distance_lbl.set_text("%.03f ft" % (rdistance * 1000 / 0.3048))
                     else:
-                        self.distance_lbl.set_text("%.01f" % (rdistance * 1000))
-                        pass
+                        self.distance_lbl.set_text("%.01f m" % (rdistance * 1000))
                     print "Previous radar : %s, %s" % (
                             self.previousradarid,  self.previousradardistance)
                     print "Current radar : %s, %s" % (rid,  rdistance)
@@ -260,7 +360,11 @@ class  roadrunnerApp(hildon.Program):
                                                     rid==self.previousradarid) & (
                                                     device.fix[11] > 10):
                         print "main : start_alert"
-                        self.alert_label.set_markup("<span size='250000'><b>%.0f</b></span>" % (rdistance*1000))
+                        if self.unit == 'miles':
+                            val = rdistance * 1000 / 0.3048
+                        else:
+                            val = rdistance * 1000
+                        self.alert_label.set_markup("<span size='250000'><b>%.0f</b></span>" % (val))
                         self.start_alert()
                         pass
                     else:
@@ -339,7 +443,10 @@ class  roadrunnerApp(hildon.Program):
                 ('unlocked',),
                 False, True)
             gobject.timeout_add(10000, self.keep_display_on)
-            gobject.timeout_add(1500, self.activate_vibrator)
+            if self.vibration == 'True':
+                gobject.timeout_add(1500, self.activate_vibrator)
+            if self.sound == 'True':
+                gobject.timeout_add(2000, self.activate_beep)
             self.alert = True
             self.alert_window.show_all()
         
@@ -374,6 +481,13 @@ class  roadrunnerApp(hildon.Program):
             return True
         else:
             return False
+            
+    def activate_beep(self):
+        hildon.hildon_play_system_sound(BEEP)
+        if self.alert == True:
+            return True
+        else:
+            return False
     
     
     def test_alert(self):
@@ -400,3 +514,15 @@ class  roadrunnerApp(hildon.Program):
         reponse = boite.run()
         boite.destroy()
 
+    def display_about_dialog(self, widget,  app):
+        about_window = hildon.StackableWindow()    
+        vbox = gtk.VBox(False, 0)
+        label = gtk.Label()
+        label.set_markup(ABOUT_MESSAGE)
+        vbox.pack_start(label, True, True, 0)
+        i = gtk.Image()
+        i.set_from_file("/usr/share/icons/hicolor/64x64/hildon/roadrunner.png")
+        vbox.pack_start(i, True, True, 0)
+        about_window.add(vbox)  
+        about_window.set_title("About Roadrunner")
+        about_window.show_all()
